@@ -184,7 +184,7 @@ enum ast_json_type ast_json_typeof(const struct ast_json *value);
  * \since 12.0.0
  * \param type Type to convert to string.
  * \return Simple string for the type name (object, array, string, etc.)
- * \return \c "?" for invalid types.
+ * \retval "?" for invalid types.
  */
 const char *ast_json_typename(enum ast_json_type type);
 
@@ -271,24 +271,24 @@ struct ast_json *ast_json_null(void);
 /*!
  * \brief Check if \a value is JSON true.
  * \since 12.0.0
- * \return True (non-zero) if \a value == \ref ast_json_true().
- * \return False (zero) otherwise..
+ * \retval True (non-zero) if \a value == \ref ast_json_true().
+ * \retval False (zero) otherwise..
  */
 int ast_json_is_true(const struct ast_json *value);
 
 /*!
  * \brief Check if \a value is JSON false.
  * \since 12.0.0
- * \return True (non-zero) if \a value == \ref ast_json_false().
- * \return False (zero) otherwise.
+ * \retval True (non-zero) if \a value == \ref ast_json_false().
+ * \retval False (zero) otherwise.
  */
 int ast_json_is_false(const struct ast_json *value);
 
 /*!
  * \brief Check if \a value is JSON null.
  * \since 12.0.0
- * \return True (non-zero) if \a value == \ref ast_json_false().
- * \return False (zero) otherwise.
+ * \retval True (non-zero) if \a value == \ref ast_json_false().
+ * \retval False (zero) otherwise.
  */
 int ast_json_is_null(const struct ast_json *value);
 
@@ -304,7 +304,7 @@ int ast_json_is_null(const struct ast_json *value);
  *
  * \param value Value of new JSON string.
  * \return Newly constructed string element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_string_create(const char *value);
 
@@ -313,7 +313,7 @@ struct ast_json *ast_json_string_create(const char *value);
  * \since 12.0.0
  * \param string JSON string.
  * \return Value of the string.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 const char *ast_json_string_get(const struct ast_json *string);
 
@@ -325,8 +325,8 @@ const char *ast_json_string_get(const struct ast_json *string);
  *
  * \param string JSON string to modify.
  * \param value New value to store in \a string.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_string_set(struct ast_json *string, const char *value);
 
@@ -338,7 +338,7 @@ int ast_json_string_set(struct ast_json *string, const char *value);
  *
  * \param format \c printf style format string.
  * \return Newly allocated string.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_stringf(const char *format, ...) __attribute__((format(printf, 1, 2)));
 
@@ -349,8 +349,10 @@ struct ast_json *ast_json_stringf(const char *format, ...) __attribute__((format
  * The formatted value must be a valid ASCII or UTF-8 encoded string.
  *
  * \param format \c printf style format string.
+ * \param args
+ *
  * \return Newly allocated string.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_vstringf(const char *format, va_list args) __attribute__((format(printf, 1, 0)));
 
@@ -363,7 +365,7 @@ struct ast_json *ast_json_vstringf(const char *format, va_list args) __attribute
  * \since 12.0.0
  * \param value Value of the new JSON integer.
  * \return Newly allocated integer.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_integer_create(intmax_t value);
 
@@ -372,7 +374,7 @@ struct ast_json *ast_json_integer_create(intmax_t value);
  * \since 12.0.0
  * \param integer JSON integer.
  * \return Value of a JSON integer.
- * \return 0 if \a integer is not a JSON integer.
+ * \retval 0 if \a integer is not a JSON integer.
  */
 intmax_t ast_json_integer_get(const struct ast_json *integer);
 
@@ -381,8 +383,8 @@ intmax_t ast_json_integer_get(const struct ast_json *integer);
  * \since 12.0.0
  * \param integer JSON integer to modify.
  * \param value New value for \a integer.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_integer_set(struct ast_json *integer, intmax_t value);
 
@@ -391,7 +393,7 @@ int ast_json_integer_set(struct ast_json *integer, intmax_t value);
  * \since 12.0.0
  * \param value Value of the new JSON real number.
  * \return Newly allocated real number.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_real_create(double value);
 
@@ -400,17 +402,17 @@ struct ast_json *ast_json_real_create(double value);
  * \since 12.0.0
  * \param real JSON real number.
  * \return Value of a JSON real number.
- * \return 0 if \a real is not a JSON real number.
+ * \retval 0 if \a real is not a JSON real number.
  */
 double ast_json_real_get(const struct ast_json *real);
 
 /*!
  * \brief Set the value of a JSON real number.
  * \since 12.0.0
- * \param integer JSON real number to modify.
+ * \param real JSON real number to modify.
  * \param value New value for \a real.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_real_set(struct ast_json *real, double value);
 
@@ -422,7 +424,7 @@ int ast_json_real_set(struct ast_json *real, double value);
  * \brief Create a empty JSON array.
  * \since 12.0.0
  * \return Newly allocated array.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_array_create(void);
 
@@ -431,7 +433,7 @@ struct ast_json *ast_json_array_create(void);
  * \since 12.0.0
  * \param array JSON array.
  * \return Size of \a array.
- * \return 0 if array is not a JSON array.
+ * \retval 0 if array is not a JSON array.
  */
 size_t ast_json_array_size(const struct ast_json *array);
 
@@ -445,8 +447,8 @@ size_t ast_json_array_size(const struct ast_json *array);
  * \param array JSON array.
  * \param index Zero-based index into \a array.
  * \return The specified element.
- * \return \c NULL if \a array not an array.
- * \return \c NULL if \a index is out of bounds.
+ * \retval NULL if \a array not an array.
+ *              if \a index is out of bounds.
  */
 struct ast_json *ast_json_array_get(const struct ast_json *array, size_t index);
 
@@ -460,8 +462,8 @@ struct ast_json *ast_json_array_get(const struct ast_json *array, size_t index);
  * \param array JSON array to modify.
  * \param index Zero-based index into array.
  * \param value New JSON value to store in \a array at \a index.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_set(struct ast_json *array, size_t index, struct ast_json *value);
 
@@ -474,8 +476,8 @@ int ast_json_array_set(struct ast_json *array, size_t index, struct ast_json *va
  *
  * \param array JSON array to modify.
  * \param value New JSON value to store at the end of \a array.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_append(struct ast_json *array, struct ast_json *value);
 
@@ -489,8 +491,8 @@ int ast_json_array_append(struct ast_json *array, struct ast_json *value);
  * \param array JSON array to modify.
  * \param index Zero-based index into array.
  * \param value New JSON value to store in \a array at \a index.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_insert(struct ast_json *array, size_t index, struct ast_json *value);
 
@@ -499,8 +501,8 @@ int ast_json_array_insert(struct ast_json *array, size_t index, struct ast_json
  * \since 12.0.0
  * \param array JSON array to modify.
  * \param index Zero-based index into array.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_remove(struct ast_json *array, size_t index);
 
@@ -508,8 +510,8 @@ int ast_json_array_remove(struct ast_json *array, size_t index);
  * \brief Remove all elements from an array.
  * \since 12.0.0
  * \param array JSON array to clear.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_clear(struct ast_json *array);
 
@@ -521,8 +523,8 @@ int ast_json_array_clear(struct ast_json *array);
  *
  * \param array JSON array to modify.
  * \param tail JSON array with contents to append to \a array.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_extend(struct ast_json *array, struct ast_json *tail);
 
@@ -534,16 +536,25 @@ int ast_json_array_extend(struct ast_json *array, struct ast_json *tail);
  * \brief Create a new JSON object.
  * \since 12.0.0
  * \return Newly allocated object.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_object_create(void);
 
+/*!
+ * \brief Create a new JSON object using the given variables
+ * \param variables A list of Asterisk variables
+ * \param excludes Comma separated string of variable names to exclude (optional)
+ * \return Newly allocated object.
+ * \retval NULL on error.
+ */
+struct ast_json *ast_json_object_create_vars(const struct ast_variable *variables, const char *excludes);
+
 /*!
  * \brief Get size of JSON object.
  * \since 12.0.0
  * \param object JSON object.
  * \return Size of \a object.
- * \return Zero of \a object is not a JSON object.
+ * \retval Zero of \a object is not a JSON object.
  */
 size_t ast_json_object_size(struct ast_json *object);
 
@@ -557,7 +568,7 @@ size_t ast_json_object_size(struct ast_json *object);
  * \param object JSON object.
  * \param key Key of field to look up.
  * \return Value with given \a key.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_object_get(struct ast_json *object, const char *key);
 
@@ -568,10 +579,28 @@ struct ast_json *ast_json_object_get(struct ast_json *object, const char *key);
  * \param object JSON object.
  * \param key Key of string field to look up.
  * \return String value of given \a key.
- * \return \c NULL on error, or key value is not a string.
+ * \retval NULL on error, or key value is not a string.
  */
 #define ast_json_object_string_get(object, key) ast_json_string_get(ast_json_object_get(object, key))
 
+/*!
+ * \brief Get an integer field from a JSON object.
+ * \param object JSON object.
+ * \param key Key of integer field to look up.
+ * \return Value of a JSON integer.
+ * \retval 0 if \a integer is not a JSON integer.
+ */
+#define ast_json_object_integer_get(object, key) ast_json_integer_get(ast_json_object_get(object, key))
+
+/*!
+ * \brief Get a double field from a JSON object.
+ * \param object JSON object.
+ * \param key Key of double field to look up.
+ * \return Value of a JSON double.
+ * \retval 0 if \a real is not a JSON real number.
+ */
+#define ast_json_object_real_get(object, key) ast_json_real_get(ast_json_object_get(object, key))
+
 /*!
  * \brief Set a field in a JSON object.
  * \since 12.0.0
@@ -582,8 +611,8 @@ struct ast_json *ast_json_object_get(struct ast_json *object, const char *key);
  * \param object JSON object to modify.
  * \param key Key of field to set.
  * \param value JSON value to set for field.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_set(struct ast_json *object, const char *key, struct ast_json *value);
 
@@ -593,7 +622,7 @@ int ast_json_object_set(struct ast_json *object, const char *key, struct ast_jso
  *
  * \param object JSON object to modify.
  * \param key Key of field to delete.
- * \return 0 on success, or -1 if key does not exist.
+ * \retval 0 on success, or -1 if key does not exist.
  */
 int ast_json_object_del(struct ast_json *object, const char *key);
 
@@ -601,8 +630,8 @@ int ast_json_object_del(struct ast_json *object, const char *key);
  * \brief Delete all elements from a JSON object.
  * \since 12.0.0
  * \param object JSON object to clear.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_clear(struct ast_json *object);
 
@@ -615,8 +644,8 @@ int ast_json_object_clear(struct ast_json *object);
  *
  * \param object JSON object to modify.
  * \param other JSON object to copy into \a object.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_update(struct ast_json *object, struct ast_json *other);
 
@@ -630,8 +659,8 @@ int ast_json_object_update(struct ast_json *object, struct ast_json *other);
  *
  * \param object JSON object to modify.
  * \param other JSON object to copy into \a object.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_update_existing(struct ast_json *object, struct ast_json *other);
 
@@ -645,8 +674,8 @@ int ast_json_object_update_existing(struct ast_json *object, struct ast_json *ot
  *
  * \param object JSON object to modify.
  * \param other JSON object to copy into \a object.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_update_missing(struct ast_json *object, struct ast_json *other);
 
@@ -670,8 +699,8 @@ struct ast_json_iter;
  *
  * \param object JSON object.
  * \return Iterator to the first field in \a object.
- * \return \c NULL \a object is empty.
- * \return \c NULL on error.
+ * \retval NULL \a object is empty.
+ *              on error.
  */
 struct ast_json_iter *ast_json_object_iter(struct ast_json *object);
 
@@ -684,8 +713,8 @@ struct ast_json_iter *ast_json_object_iter(struct ast_json *object);
  * \param object JSON object to iterate.
  * \param key Key of field to lookup.
  * \return Iterator pointing to the field with the given \a key.
- * \return \c NULL if \a key does not exist.
- * \return \c NULL on error.
+ * \retval NULL if \a key does not exist.
+ *              on error.
  */
 struct ast_json_iter *ast_json_object_iter_at(struct ast_json *object, const char *key);
 
@@ -695,7 +724,7 @@ struct ast_json_iter *ast_json_object_iter_at(struct ast_json *object, const cha
  * \param object JSON object \a iter was obtained from.
  * \param iter JSON object iterator.
  * \return Iterator to next field in \a object.
- * \return \c NULL if \a iter was the last field.
+ * \retval NULL if \a iter was the last field.
  */
 struct ast_json_iter *ast_json_object_iter_next(struct ast_json *object, struct ast_json_iter *iter);
 
@@ -723,14 +752,14 @@ struct ast_json *ast_json_object_iter_value(struct ast_json_iter *iter);
  * \brief Set the value of the field pointed to by an iterator.
  * \since 12.0.0
  *
- * \note The object steals the \a value reference even if it returns error;
+ * \note The object steals the \p value reference even if it returns error;
  * use ast_json_ref() to safely keep a pointer to it.
  *
- * \param object JSON object \a iter was obtained from.
+ * \param object JSON object \p iter was obtained from.
  * \param iter JSON object iterator.
- * \param value JSON value to store in \iter's field.
- * \return 0 on success.
- * \return -1 on error.
+ * \param value JSON value to store in \p iter's field.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_iter_set(struct ast_json *object, struct ast_json_iter *iter, struct ast_json *value);
 
@@ -758,7 +787,7 @@ enum ast_json_encoding_format
  *
  * \param root JSON value.
  * \return String encoding of \a root.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 #define ast_json_dump_string(root) ast_json_dump_string_format(root, AST_JSON_COMPACT)
 
@@ -771,7 +800,7 @@ enum ast_json_encoding_format
  * \param root JSON value.
  * \param format encoding format type.
  * \return String encoding of \a root.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 char *ast_json_dump_string_format(struct ast_json *root, enum ast_json_encoding_format format);
 
@@ -786,8 +815,8 @@ char *ast_json_dump_string_format(struct ast_json *root, enum ast_json_encoding_
  * \param root JSON value.
  * \param dst \ref ast_str to store JSON encoding.
  * \param format encoding format type.
- * \return 0 on success.
- * \return -1 on error. The contents of \a dst are undefined.
+ * \retval 0 on success.
+ * \retval -1 on error. The contents of \a dst are undefined.
  */
 int ast_json_dump_str_format(struct ast_json *root, struct ast_str **dst, enum ast_json_encoding_format format);
 
@@ -800,8 +829,8 @@ int ast_json_dump_str_format(struct ast_json *root, struct ast_str **dst, enum a
  * \param root JSON value.
  * \param output File to write JSON encoding to.
  * \param format encoding format type.
- * \return 0 on success.
- * \return -1 on error. The contents of \a output are undefined.
+ * \retval 0 on success.
+ * \retval -1 on error. The contents of \a output are undefined.
  */
 int ast_json_dump_file_format(struct ast_json *root, FILE *output, enum ast_json_encoding_format format);
 
@@ -814,8 +843,8 @@ int ast_json_dump_file_format(struct ast_json *root, FILE *output, enum ast_json
  * \param root JSON value.
  * \param path Path to file to write JSON encoding to.
  * \param format encoding format type.
- * \return 0 on success.
- * \return -1 on error. The contents of \a output are undefined.
+ * \retval 0 on success.
+ * \retval -1 on error. The contents of \a output are undefined.
  */
 int ast_json_dump_new_file_format(struct ast_json *root, const char *path, enum ast_json_encoding_format format);
 
@@ -835,7 +864,7 @@ struct ast_json_error {
 	int position;
 	/*! Error message */
 	char text[AST_JSON_ERROR_TEXT_LENGTH];
-	/*! Source of the error (filename or <string>) */
+	/*! Source of the error (filename or \<string\>) */
 	char source[AST_JSON_ERROR_TEXT_LENGTH];
 };
 
@@ -845,7 +874,7 @@ struct ast_json_error {
  * \param input String to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_string(const char *input, struct ast_json_error *error);
 
@@ -855,7 +884,7 @@ struct ast_json *ast_json_load_string(const char *input, struct ast_json_error *
  * \param input \ref ast_str to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_str(const struct ast_str *input, struct ast_json_error *error);
 
@@ -866,7 +895,7 @@ struct ast_json *ast_json_load_str(const struct ast_str *input, struct ast_json_
  * \param buflen Length of \a buffer.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_buf(const char *buffer, size_t buflen, struct ast_json_error *error);
 
@@ -876,7 +905,7 @@ struct ast_json *ast_json_load_buf(const char *buffer, size_t buflen, struct ast
  * \param input \c FILE to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_file(FILE *input, struct ast_json_error *error);
 
@@ -886,7 +915,7 @@ struct ast_json *ast_json_load_file(FILE *input, struct ast_json_error *error);
  * \param path Path of file to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_new_file(const char *path, struct ast_json_error *error);
 
@@ -920,8 +949,8 @@ struct ast_json *ast_json_vpack(char const *format, va_list ap);
  *
  * \param lhs Value to compare.
  * \param rhs Other value to compare.
- * \return True (non-zero) if \a lhs and \a rhs are equal.
- * \return False (zero) if they are not.
+ * \retval True (non-zero) if \a lhs and \a rhs are equal.
+ * \retval False (zero) if they are not.
  */
 int ast_json_equal(const struct ast_json *lhs, const struct ast_json *rhs);
 
@@ -933,7 +962,7 @@ int ast_json_equal(const struct ast_json *lhs, const struct ast_json *rhs);
  *
  * \param value JSON value to copy.
  * \return Shallow copy of \a value.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_copy(const struct ast_json *value);
 
@@ -945,7 +974,7 @@ struct ast_json *ast_json_copy(const struct ast_json *value);
  *
  * \param value JSON value to copy.
  * \return Deep copy of \a value.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_deep_copy(const struct ast_json *value);
 
@@ -961,8 +990,8 @@ struct ast_json *ast_json_deep_copy(const struct ast_json *value);
  * \brief Simple name/number pair.
  * \param name Name
  * \param number Number
- * \return NULL if error (non-UTF8 characters, NULL inputs, etc.)
  * \return JSON object with name and number fields
+ * \retval NULL on error (non-UTF8 characters, NULL inputs, etc.)
  */
 struct ast_json *ast_json_name_number(const char *name, const char *number);
 
@@ -976,7 +1005,7 @@ struct ast_json *ast_json_name_number(const char *name, const char *number);
  * \param tv \c timeval to encode.
  * \param zone Text string of a standard system zoneinfo file.  If NULL, the system localtime will be used.
  * \return JSON string with ISO 8601 formatted date/time.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_timeval(const struct timeval tv, const char *zone);
 
@@ -988,7 +1017,7 @@ struct ast_json *ast_json_timeval(const struct timeval tv, const char *zone);
  * \param addr ast_sockaddr to encode
  * \param transport_type ast_transport to include in the address string if any. Should just be one.
  * \return JSON string containing the IP address with optional transport information
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_ipaddr(const struct ast_sockaddr *addr, enum ast_transport transport_type);
 
@@ -1031,8 +1060,8 @@ struct ast_json_payload {
  *
  * \param json the ast_json blob we are loading
  *
+ * \return pointer to the ast_json_payload created
  * \retval NULL if we fail to alloc it
- * \retval pointer to the ast_json_payload created
  */
 struct ast_json_payload *ast_json_payload_create(struct ast_json *json);
 
